diff --git a/src/fl_utf.c b/src/fl_utf.c
index 31572c4..97d5f6e 100644
--- a/src/fl_utf.c
+++ b/src/fl_utf.c
@@ -321,9 +321,9 @@ int fl_utf8encode(unsigned ucs, char* buf) {
     return 4;
   } else {
     /* encode 0xfffd: */
-    buf[0] = 0xefU;
-    buf[1] = 0xbfU;
-    buf[2] = 0xbdU;
+    buf[0] = (char)0xef;
+    buf[1] = (char)0xbf;
+    buf[2] = (char)0xbd;
     return 3;
   }
 }
@@ -813,7 +813,7 @@ unsigned fl_utf8to_mb(const char* src, unsigned srclen,
     }
     if (dstlen) {
       ret = wcstombs(dst, buf, dstlen);
-      if (ret >= dstlen-1) ret = wcstombs(0,buf,0);
+      if (ret >= (int)dstlen-1) ret = wcstombs(0,buf,0);
     } else {
       ret = wcstombs(0,buf,0);
     }
diff --git a/src/vsnprintf.c b/src/vsnprintf.c
index be93ba6..39114e2 100644
--- a/src/vsnprintf.c
+++ b/src/vsnprintf.c
@@ -125,7 +125,7 @@ int fl_vsnprintf(char* buffer, size_t bufsize, const char* format, va_list ap) {
 	case 'e' :
 	case 'f' :
 	case 'g' :
-	  if ((width + 2) > sizeof(temp)) break;
+	  if ((width + 2) > (int)sizeof(temp)) break;
 
 	  sprintf(temp, tformat, va_arg(ap, double));
 
@@ -150,7 +150,7 @@ int fl_vsnprintf(char* buffer, size_t bufsize, const char* format, va_list ap) {
 	case 'o' :
 	case 'u' :
 	case 'x' :
-	  if ((width + 2) > sizeof(temp)) break;
+	  if ((width + 2) > (int)sizeof(temp)) break;
 
 #ifdef HAVE_LONG_LONG
 	  if (size == 'L')
@@ -176,7 +176,7 @@ int fl_vsnprintf(char* buffer, size_t bufsize, const char* format, va_list ap) {
 	  break;
 	    
 	case 'p' : /* Pointer value */
-	  if ((width + 2) > sizeof(temp)) break;
+	  if ((width + 2) > (int)sizeof(temp)) break;
 
 	  sprintf(temp, tformat, va_arg(ap, void *));
 
diff --git a/src/xutf8/utf8Wrap.c b/src/xutf8/utf8Wrap.c
index 9f12c93..1ed00e9 100644
--- a/src/xutf8/utf8Wrap.c
+++ b/src/xutf8/utf8Wrap.c
@@ -398,7 +398,7 @@ XUtf8DrawRtlString(Display 		*display,
     while (fnum < nb_font) {
       if (fonts[fnum] && ucs2fontmap(glyph, ucs, encodings[fnum]) >= 0) {
 	if (encodings[fnum] != 0 ||
-	    (ucs >= ranges[fnum * 2] && ucs <= ranges[fnum * 2 + 1])) {
+	    ((int)ucs >= ranges[fnum * 2] && (int)ucs <= ranges[fnum * 2 + 1])) {
 	  break;
 	}
       }
@@ -515,8 +515,8 @@ XUtf8DrawString(Display 	*display,
     while (fnum < nb_font) {
       if (fonts[fnum] && ucs2fontmap(glyph, ucs, encodings[fnum]) >= 0) {
 	if (encodings[fnum] != 0 ||
-	    (ucs >= ranges[fnum * 2] &&
-	    ucs <= ranges[fnum * 2 + 1])) {
+	    ((int)ucs >= ranges[fnum * 2] &&
+	     (int)ucs <= ranges[fnum * 2 + 1])) {
 	  break;
 	}
       }
@@ -648,8 +648,8 @@ XUtf8_measure_extents(
     while (fnum < nb_font) {
       if (fonts[fnum] && ucs2fontmap(glyph, ucs, encodings[fnum]) >= 0) {
 	if (encodings[fnum] != 0 ||
-	    (ucs >= ranges[fnum * 2] &&
-	    ucs <= ranges[fnum * 2 + 1])) {
+	    ((int)ucs >= ranges[fnum * 2] &&
+	     (int)ucs <= ranges[fnum * 2 + 1])) {
 	  break;
 	}
       }
@@ -773,8 +773,8 @@ XUtf8TextWidth(XUtf8FontStruct 	*font_set,
     while (fnum < nb_font) {
       if (fonts[fnum] && ucs2fontmap(glyph, ucs, encodings[fnum]) >= 0) {
 	if (encodings[fnum] != 0 ||
-		(ucs >= ranges[fnum * 2] &&
-		ucs <= ranges[fnum * 2 + 1])) {
+		((int)ucs >= ranges[fnum * 2] &&
+		 (int)ucs <= ranges[fnum * 2 + 1])) {
 	  break;
 	}
       }
@@ -863,8 +863,8 @@ XGetUtf8FontAndGlyph(XUtf8FontStruct  *font_set,
   while (fnum < nb_font) {
     if (fonts[fnum] && ucs2fontmap(glyph, ucs, encodings[fnum]) >= 0) {
       if (encodings[fnum] != 0 ||
-          (ucs >= ranges[fnum * 2] &&
-	  ucs <= ranges[fnum * 2 + 1])) {
+	  ((int)ucs >= ranges[fnum * 2] &&
+	   (int)ucs <= ranges[fnum * 2 + 1])) {
 	break;
       }
     }
@@ -937,8 +937,8 @@ XUtf8UcsWidth(XUtf8FontStruct  *font_set,
   while (fnum < nb_font) {
     if (fonts[fnum] &&
 	ucs2fontmap(glyph, ucs, encodings[fnum]) >= 0) {
-      if (encodings[fnum] != 0 || (ucs >= ranges[fnum * 2] &&
-	  ucs <= ranges[fnum * 2 + 1])) {
+      if (encodings[fnum] != 0 || ((int)ucs >= ranges[fnum * 2] &&
+	  (int)ucs <= ranges[fnum * 2 + 1])) {
 	break;
       }
     }
